"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = exports.getActionDefaultInputs = exports.normalizeConfigKeys = exports.normalizeConfigKey = void 0;
const cosmiconfig_1 = require("cosmiconfig");
const fs_1 = require("fs");
const path_1 = require("path");
const js_yaml_1 = require("js-yaml");
const misc_1 = require("./misc");
const normalizeConfigKey = (key) => key.replace(/[-\s]+/g, '_').toUpperCase();
exports.normalizeConfigKey = normalizeConfigKey;
const normalizeConfigKeys = (config) => Object.assign({}, ...Object.keys(config).map(key => ({
    [exports.normalizeConfigKey(key)]: config[key],
})));
exports.normalizeConfigKeys = normalizeConfigKeys;
/* istanbul ignore next */
const getActionSettingFile = () => fs_1.existsSync(path_1.resolve(__dirname, '../../release-github-actions/action.yml')) ?
    path_1.resolve(__dirname, '../../release-github-actions/action.yml') :
    path_1.resolve(__dirname, '../node_modules/@technote-space/release-github-actions/action.yml');
const getActionDefaultInputs = () => {
    const actionSetting = js_yaml_1.load(fs_1.readFileSync(getActionSettingFile(), 'utf8'));
    const inputs = actionSetting['inputs'];
    return Object.assign({}, ...Object.keys(inputs).filter(key => 'default' in inputs[key]).map(key => ({
        [exports.normalizeConfigKey(key)]: `${inputs[key].default}`,
    })));
};
exports.getActionDefaultInputs = getActionDefaultInputs;
const getConfig = (dir, isTest) => {
    var _a, _b;
    const explorer = cosmiconfig_1.cosmiconfigSync('releasega');
    const { config = {} } = explorer.search(dir) || {};
    if (!('owner' in config) || !('repo' in config)) {
        const { owner, repo } = misc_1.getRepository(dir);
        if ('OWNER' in config) {
            config.owner = config.OWNER;
            delete config.OWNER;
        }
        if ('REPO' in config) {
            config.repo = config.REPO;
            delete config.REPO;
        }
        if (!('owner' in config)) {
            config.owner = owner;
        }
        if (!('repo' in config)) {
            config.repo = repo;
        }
    }
    return Object.assign(Object.assign({}, config), { inputs: Object.assign(Object.assign(Object.assign({}, exports.getActionDefaultInputs()), {
            TEST_TAG_PREFIX: isTest ? 'test/' : '',
            BRANCH_NAME: 'gh-actions',
        }), exports.normalizeConfigKeys((_b = (_a = config.inputs) !== null && _a !== void 0 ? _a : config.INPUTS) !== null && _b !== void 0 ? _b : {})) });
};
exports.getConfig = getConfig;
