"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = void 0;
const commander_1 = require("commander");
const misc_1 = require("./misc");
const wrapper_1 = require("./wrapper");
const config_1 = require("./config");
const env_1 = require("./env");
const execute = () => __awaiter(void 0, void 0, void 0, function* () {
    const program = new commander_1.Command();
    program
        .option('-t, --tag <tag>', 'tag name')
        .option('--token <token>', 'token')
        .option('-b, --branch [branch]', 'branch name')
        .option('-w, --workspace [workspace]', 'working directory name', '.')
        .option('-p, --package [package]', 'package file directory name', process.cwd())
        .option('-n, --dry-run', 'show what would have been pushed')
        .option('--test', 'whether it is test')
        .parse(process.argv);
    const options = program.opts();
    const token = options.token || env_1.loadTokenFromEnv(options.package);
    if (!token) {
        throw new Error('<token> is required.');
    }
    process.env.INPUT_GITHUB_TOKEN = token;
    const helper = misc_1.getGitHelper();
    const config = config_1.getConfig(options.package, options.test);
    const args = yield misc_1.getContextArgs(helper, options.tag, options.branch, options.package, options.test, config);
    env_1.setEnv(config, options.workspace);
    if (!wrapper_1.isValidContext(args)) {
        console.log('This is not target tag');
        return;
    }
    yield wrapper_1.prepare(helper, args);
    yield wrapper_1.commit(helper, args);
    if (!options.dryRun) {
        yield wrapper_1.push(helper, args);
    }
});
exports.execute = execute;
