"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGitHelper = exports.getContext = exports.getContextArgs = exports.getRepository = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const github_action_helper_1 = require("@technote-space/github-action-helper");
const github_action_log_helper_1 = require("@technote-space/github-action-log-helper");
const getRepository = (dir) => {
    var _a, _b, _c, _d;
    const json = JSON.parse(fs_1.readFileSync(path_1.resolve(dir, 'package.json'), { encoding: 'utf8' }));
    const url = json ? (_c = (_b = (_a = json.repository) === null || _a === void 0 ? void 0 : _a.url) !== null && _b !== void 0 ? _b : json.homepage) !== null && _c !== void 0 ? _c : (_d = json.bugs) === null || _d === void 0 ? void 0 : _d.url : '';
    if (!url) {
        throw new Error('Invalid package file.');
    }
    const matches = url.match(/github\.com\/([^/]+)\/([^/.#?]+)/);
    if (!matches) {
        throw new Error('Invalid url. [https://github.com/<orner>/<repo>(.git|/issues|#readme|...)]');
    }
    return {
        owner: matches[1],
        repo: matches[2],
    };
};
exports.getRepository = getRepository;
const getContextArgs = (helper, tagName, branch, dir, isTest, config) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    if (!tagName) {
        if (!isTest || !((_a = config.inputs) === null || _a === void 0 ? void 0 : _a.TEST_TAG_PREFIX)) {
            throw new Error('<tag> is required.');
        }
        const version = yield helper.getNewPatchVersion(dir);
        (new github_action_log_helper_1.Logger()).info('version: %s', version);
        return Object.assign(Object.assign({}, config), { tagName: config.inputs.TEST_TAG_PREFIX + version, branch });
    }
    return Object.assign(Object.assign({}, config), { tagName, branch });
});
exports.getContextArgs = getContextArgs;
const getContext = (args) => ({
    payload: {
        action: 'published',
        release: {
            'tag_name': args.tagName,
        },
    },
    eventName: 'release',
    ref: `refs/heads/${args.branch || 'master'}`,
    sha: 'FETCH_HEAD',
    workflow: '',
    action: '',
    actor: '',
    issue: {
        owner: '',
        repo: '',
        number: 1,
    },
    repo: {
        owner: args.owner,
        repo: args.repo,
    },
    job: '',
    runId: 1,
    runNumber: 1,
});
exports.getContext = getContext;
const getGitHelper = () => new github_action_helper_1.GitHelper(new github_action_log_helper_1.Logger());
exports.getGitHelper = getGitHelper;
