"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.push = exports.commit = exports.prepare = exports.prepareFiles = exports.isValidContext = void 0;
const fs_1 = require("fs");
const github_action_helper_1 = require("@technote-space/github-action-helper");
const github_action_log_helper_1 = require("@technote-space/github-action-log-helper");
const command = __importStar(require("@technote-space/release-github-actions/lib/utils/command"));
const misc = __importStar(require("@technote-space/release-github-actions/lib/utils/misc"));
const misc_1 = require("./misc");
const isValidContext = (args) => misc.isValidContext(misc_1.getContext(args));
exports.isValidContext = isValidContext;
const prepareFiles = (logger, com, helper, args, context) => __awaiter(void 0, void 0, void 0, function* () {
    const { buildDir, pushDir } = misc.getParams(context);
    fs_1.mkdirSync(buildDir, { recursive: true });
    if (args.branch) {
        logger.startProcess('Cloning the remote repo for build...');
        yield helper.checkout(buildDir, context);
    }
    else {
        logger.startProcess('Copying current source to build directory...');
        yield com.execAsync({
            command: 'rsync',
            args: [
                '-ac',
                '-C',
                '--filter=:- .gitignore',
                '--exclude',
                '.git',
                '--exclude',
                '.work',
                '--exclude',
                '.github',
                '--delete',
                './',
                buildDir,
            ],
        });
    }
    logger.startProcess('Running build for release...');
    yield helper.runCommand(buildDir, misc.getBuildCommands(buildDir, pushDir));
});
exports.prepareFiles = prepareFiles;
const prepare = (helper, args) => __awaiter(void 0, void 0, void 0, function* () {
    const context = misc_1.getContext(args);
    const { buildDir, pushDir } = misc.getParams(context);
    const logger = new github_action_log_helper_1.Logger(command.replaceDirectory(context));
    const com = new github_action_helper_1.Command(logger);
    yield com.execAsync({ command: `rm -rdf ${buildDir} ${pushDir}` });
    yield command.clone(logger, helper, context);
    yield command.checkBranch(yield helper.getCurrentBranchName(pushDir), logger, helper, context);
    yield exports.prepareFiles(logger, com, helper, args, context);
    yield command.createBuildInfoFile(logger, context);
    yield command.copyFiles(logger, com, context);
});
exports.prepare = prepare;
const commit = (helper, args) => __awaiter(void 0, void 0, void 0, function* () {
    const context = misc_1.getContext(args);
    const logger = new github_action_log_helper_1.Logger(command.replaceDirectory(context));
    yield command.config(logger, helper, context);
    yield command.commit(helper, context);
});
exports.commit = commit;
const push = (helper, args) => __awaiter(void 0, void 0, void 0, function* () {
    const context = misc_1.getContext(args);
    const logger = new github_action_log_helper_1.Logger(command.replaceDirectory(context));
    yield command.push(logger, helper, misc_1.getContext(args));
});
exports.push = push;
